==> servicecatalog-model-6.8.0-sources.jar: io/fabric8/servicecatalog/api/model/SecretKeyReferenceFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretKeyReferenceFluent<A extends SecretKeyReferenceFluent<A>> extends BaseFluent<A>{
  public SecretKeyReferenceFluent() {
  }
  public SecretKeyReferenceFluent(SecretKeyReference instance) {
    instance = (instance != null ? instance : new SecretKeyReference());

    if (instance != null) {
      this.withKey(instance.getKey());
      this.withName(instance.getName());
      this.withKey(instance.getKey());
      this.withName(instance.getName());
    }
  }
  private String key;
  private String name;
  public String getKey() {
    return this.key;
  }
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  public boolean hasKey() {
    return this.key != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretKeyReferenceFluent that = (SecretKeyReferenceFluent) o;
    if (!java.util.Objects.equals(key, that.key)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(key,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/SecretKeyReferenceFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SecretKeyReferenceFluent<A extends SecretKeyReferenceFluent<A>> extends BaseFluent<A>{
  public SecretKeyReferenceFluent() {
  }
  
  public SecretKeyReferenceFluent(SecretKeyReference instance) {
    this.copyInstance(instance);
  }
  private String key;
  private String name;
  
  protected void copyInstance(SecretKeyReference instance) {
    instance = (instance != null ? instance : new SecretKeyReference());
  
    if (instance != null) {
        this.withKey(instance.getKey());
        this.withName(instance.getName());
        this.withKey(instance.getKey());
        this.withName(instance.getName());
      }
  }
  
  public String getKey() {
    return this.key;
  }
  
  public A withKey(String key) {
    this.key=key; return (A) this;
  }
  
  public boolean hasKey() {
    return this.key != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretKeyReferenceFluent that = (SecretKeyReferenceFluent) o;
    if (!java.util.Objects.equals(key, that.key)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(key,  name,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (key != null) { sb.append("key:"); sb.append(key + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  

}
